==> bplan-base-globals-1.1.0-0b4347.zip: lang/pl/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'pl',
    'language' => 'Polski',
    'locale' => 'pl_PL',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value zł',
    'currency.format.negative' => '-:value zł',
    'currency.iso4217.alpha'   => 'PLN',
    'currency.iso4217.numeric' => 985,
    'currency.name'            => 'Złoty',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Grosz',
    'currency.subunit.symbol'  => 'gr',
    'currency.symbol'          => 'zł',

    'date.format'       => 'Y-m-d',
    'datetime.format'   => 'Y-m-d H:i',
    'datetime.format+'  => 'Y-m-d H:i:s',
    'datetime.format-+' => 'Y-m-d H:i',
    'datetime.format++' => 'Y-m-d H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Aktywować',
    'action.add'           => 'Dodaj',
    'action.cancel'        => 'Anuluj',
    'action.cancel-upload' => 'Anuluj przesyłanie',
    'action.change'        => 'Zmień',
    'action.close'         => 'Zamknij',
    'action.confirm'       => 'Potwierdź',
    'action.deactivate'    => 'Dezaktywuj',
    'action.delete'        => 'Usuń',
    'action.edit'          => 'Edytuj',
    'action.import'        => 'Importuj',
    'action.print'         => 'Drukuj',
    'action.save'          => 'Zapisz',
    'action.search'        => 'Szukaj',
    'action.sync'          => 'Synchronizuj',
    'action.upload'        => 'Prześlij plik',
    'action.verify'        => 'Zweryfikuj',
    'action.view'          => 'Zobacz',

    'languages' => [
        'bg' => 'Bułgarski',
        'de' => 'Niemiecki',
        'en' => 'Angielski',
        'es' => 'Hiszpański',
        'fr' => 'Francuski',
        'hu' => 'Węgierski',
        'it' => 'Włoski',
        'lt' => 'Litewski',
        'pl' => 'Polski',
        'ro' => 'Rumuński',
        'ru' => 'Rosyjski',
        'tr' => 'Turecki',
        'uk' => 'Ukraiński',
    ],

    'option.yes' => 'Tak',
    'option.no'  => 'Nie',

    'required-hint'   => 'Pola oznaczone (<span class="required-marker">:marker</span>) są wymagane',
    'required-marker' => '*',

    'select-option.please-select' => ' -- Wybierz -- ',

    'status.active'   => 'Aktywny',
    'status.expired'  => 'Wygasły',
    'status.inactive' => 'Nieaktywny',
    'status.invalid'  => 'Nieprawidłowy',
    'status.loading'  => 'Ładowanie...',
    'status.not-set'  => 'Nie ustawiono',
    'status.valid'    => 'Ważny',

];

==> bplan-base-globals-1.2.0-009337.zip: lang/pl/global.php <==
<?php
/**
 *
 * @version     1.0.$Revision:$
 * @version     SVN: $Id:$
 * @package     bplan-base/globals
 * @subpackage  Locales
 * @author      Emilio Cannarozzo <emilio.cannarozzo@bplan-solutions.de>
 * @author      Wassilios Meletiadis <wassilios.meletiadis@bplan-solutions.de>
 * @copyright   Copyright (C) 2025 bplan-solutions GmbH & Co. KG <http://www.bplan-solutions.de/>
 * /Δ\
 */

return [

    'iso-3166-1-alpha-2' => 'pl',
    'language' => 'Polski',
    'locale' => 'pl_PL',

    'currency.decimals'        => "2",
    'currency.format.string'   => ':value zł',
    'currency.format.negative' => '-:value zł',
    'currency.iso4217.alpha'   => 'PLN',
    'currency.iso4217.numeric' => 985,
    'currency.name'            => 'Złoty',
    'currency.subunit.divisor' => 100,
    'currency.subunit.name'    => 'Grosz',
    'currency.subunit.symbol'  => 'gr',
    'currency.symbol'          => 'zł',

    'date.format'       => 'Y-m-d',
    'datetime.format'   => 'Y-m-d H:i',
    'datetime.format+'  => 'Y-m-d H:i:s',
    'datetime.format-+' => 'Y-m-d H:i',
    'datetime.format++' => 'Y-m-d H:i:s',
    'time.format'       => 'H:i',
    'time.format+'      => 'H:i:s',
    'time.format-+'     => 'H:i',
    'time.format++'     => 'H:i:s',

    'number.decimal-point'       => ',',
    'number.thousands-separator' => ' ',

    'text.direction'    => 'ltr',
    'text.orientation'  => 'sideways',
    'text.writing-mode' => 'vertical-rl',

    // -------------------------------------------------------------------

    'action.activate'      => 'Aktywować',
    'action.add'           => 'Dodaj',
    'action.cancel'        => 'Anuluj',
    'action.cancel-upload' => 'Anuluj przesyłanie',
    'action.change'        => 'Zmień',
    'action.close'         => 'Zamknij',
    'action.confirm'       => 'Potwierdź',
    'action.deactivate'    => 'Dezaktywuj',
    'action.delete'        => 'Usuń',
    'action.edit'          => 'Edytuj',
    'action.import'        => 'Importuj',
    'action.print'         => 'Drukuj',
    'action.save'          => 'Zapisz',
    'action.search'        => 'Szukaj',
    'action.sync'          => 'Synchronizuj',
    'action.upload'        => 'Prześlij plik',
    'action.verify'        => 'Zweryfikuj',
    'action.view'          => 'Zobacz',

    'languages' => [
        'bg' => 'Bułgarski',
        'de' => 'Niemiecki',
        'en' => 'Angielski',
        'es' => 'Hiszpański',
        'fr' => 'Francuski',
        'hu' => 'Węgierski',
        'it' => 'Włoski',
        'lt' => 'Litewski',
        'pl' => 'Polski',
        'ro' => 'Rumuński',
        'ru' => 'Rosyjski',
        'tr' => 'Turecki',
        'uk' => 'Ukraiński',
    ],

    'option.yes' => 'Tak',
    'option.no'  => 'Nie',

    'required-hint'   => 'Pola oznaczone (<span class="required-marker">:marker</span>) są wymagane',
    'required-marker' => '*',

    'select-option.no-options-available' => 'Niedostępne opcje',
    'select-option.please-select'        => ' -- Wybierz -- ',

    'status.active'   => 'Aktywny',
    'status.expired'  => 'Wygasły',
    'status.inactive' => 'Nieaktywny',
    'status.invalid'  => 'Nieprawidłowy',
    'status.loading'  => 'Ładowanie...',
    'status.not-set'  => 'Nie ustawiono',
    'status.valid'    => 'Ważny',

];
